@@ -25,16 +25,18 @@
 #' @seealso \Sexpr[stage=render,results=rd]{parsnip:::make_seealso_list("bag_tree")}
 #' @export
 bag_tree <-
-  function(mode = "unknown",
-           cost_complexity = 0,
-           tree_depth = NULL,
-           min_n = 2,
-           class_cost = NULL,
-           engine = "rpart") {
+  function(
+    mode = "unknown",
+    cost_complexity = 0,
+    tree_depth = NULL,
+    min_n = 2,
+    class_cost = NULL,
+    engine = "rpart"
+  ) {
     args <- list(
-      cost_complexity   = enquo(cost_complexity),
-      tree_depth  = enquo(tree_depth),
-      min_n  = enquo(min_n),
+      cost_complexity = enquo(cost_complexity),
+      tree_depth = enquo(tree_depth),
+      min_n = enquo(min_n),
       class_cost = enquo(class_cost)
     )
 
@@ -58,17 +60,21 @@ bag_tree <-
 #' @inheritParams bag_tree
 #' @export
 update.bag_tree <-
-  function(object,
-           parameters = NULL,
-           cost_complexity = NULL, tree_depth = NULL, min_n = NULL,
-           class_cost = NULL,
-           fresh = FALSE, ...) {
-
+  function(
+    object,
+    parameters = NULL,
+    cost_complexity = NULL,
+    tree_depth = NULL,
+    min_n = NULL,
+    class_cost = NULL,
+    fresh = FALSE,
+    ...
+  ) {
     args <- list(
       cost_complexity = enquo(cost_complexity),
-      tree_depth      = enquo(tree_depth),
-      min_n           = enquo(min_n),
-      class_cost      = enquo(class_cost)
+      tree_depth = enquo(tree_depth),
+      min_n = enquo(min_n),
+      class_cost = enquo(class_cost)
     )
 
     update_spec(
