@@ -34,15 +34,60 @@ NULL
 
 utils::globalVariables(
   c(
-    '.', '.label', '.pred', '.row', 'data', 'engine', 'engine2', 'group',
-    'lab', 'original', 'predicted_label', 'prediction', 'value', 'type',
-    "neighbors", ".submodels", "has_submodel", "max_neighbor", "max_penalty",
-    "max_terms", "max_tree", "model", "name", "num_terms", "penalty", "trees",
-    "sub_neighbors", ".pred_class", "x", "y", "predictor_indicators",
-    "compute_intercept", "remove_intercept", "estimate", "term",
-    "call_info", "component", "component_id", "func", "tunable", "label",
-    "pkg", ".order", "item", "tunable", "has_ext", "id", "weights", "has_wts",
-    "protect", "weight_time", ".prob_cens", ".weight_cens", "s"
+    '.',
+    '.label',
+    '.pred',
+    '.row',
+    'data',
+    'engine',
+    'engine2',
+    'group',
+    'lab',
+    'original',
+    'predicted_label',
+    'prediction',
+    'value',
+    'type',
+    "neighbors",
+    ".submodels",
+    "has_submodel",
+    "max_neighbor",
+    "max_penalty",
+    "max_terms",
+    "max_tree",
+    "model",
+    "name",
+    "num_terms",
+    "penalty",
+    "trees",
+    "sub_neighbors",
+    ".pred_class",
+    "x",
+    "y",
+    "predictor_indicators",
+    "compute_intercept",
+    "remove_intercept",
+    "estimate",
+    "term",
+    "call_info",
+    "component",
+    "component_id",
+    "func",
+    "tunable",
+    "label",
+    "pkg",
+    ".order",
+    "item",
+    "tunable",
+    "has_ext",
+    "id",
+    "weights",
+    "has_wts",
+    "protect",
+    "weight_time",
+    ".prob_cens",
+    ".weight_cens",
+    "s"
   )
 )
 
@@ -55,4 +100,3 @@ release_bullets <- function() {
 }
 
 # nocov end
-
