@@ -5,7 +5,6 @@
 #' @export predict_linear_pred.model_fit
 #' @export
 predict_linear_pred.model_fit <- function(object, new_data, ...) {
-
   check_spec_pred_type(object, "linear_pred")
 
   if (inherits(object$fit, "try-error")) {
@@ -16,8 +15,9 @@ predict_linear_pred.model_fit <- function(object, new_data, ...) {
   new_data <- prepare_data(object, new_data)
 
   # preprocess data
-  if (!is.null(object$spec$method$pred$linear_pred$pre))
+  if (!is.null(object$spec$method$pred$linear_pred$pre)) {
     new_data <- object$spec$method$pred$linear_pred$pre(new_data, object)
+  }
 
   # create prediction call
   pred_call <- make_pred_call(object$spec$method$pred$linear_pred)
@@ -41,5 +41,6 @@ predict_linear_pred.model_fit <- function(object, new_data, ...) {
 #' @keywords internal
 #' @rdname other_predict
 #' @inheritParams predict_linear_pred.model_fit
-predict_linear_pred <- function(object, ...)
+predict_linear_pred <- function(object, ...) {
   UseMethod("predict_linear_pred")
+}
