@@ -63,10 +63,7 @@
 }
 
 .check_cens_type <-
-  function(surv,
-           type = "right",
-           fail = TRUE,
-           call = rlang::caller_env()) {
+  function(surv, type = "right", fail = TRUE, call = rlang::caller_env()) {
     .is_surv(surv, call = call)
     obj_type <- .extract_surv_type(surv)
     good_type <- all(obj_type %in% type)
@@ -103,13 +100,14 @@
 
 .extract_surv_status <- function(surv) {
   .is_surv(surv)
-  res <-   surv[, "status"]
+  res <- surv[, "status"]
   un_vals <- sort(unique(res))
   event_type_to_01 <-
     !(.extract_surv_type(surv) %in% c("interval", "interval2", "mstate"))
   if (
     event_type_to_01 &&
-    (identical(un_vals, 1:2) | identical(un_vals, c(1.0, 2.0))) ) {
+      (identical(un_vals, 1:2) | identical(un_vals, c(1.0, 2.0)))
+  ) {
     res <- res - 1
   }
   unname(res)
