@@ -58,8 +58,15 @@ NULL
 #' @export
 #' @keywords internal
 #' @rdname add_on_exports
-update_spec <- function(object, parameters, args_enquo_list, fresh, cls, ...,
-                        call = caller_env()) {
+update_spec <- function(
+  object,
+  parameters,
+  args_enquo_list,
+  fresh,
+  cls,
+  ...,
+  call = caller_env()
+) {
   check_bool(fresh, call = call)
   eng_args <- update_engine_parameters(object$eng_args, fresh, ...)
 
@@ -74,12 +81,15 @@ update_spec <- function(object, parameters, args_enquo_list, fresh, cls, ...,
     object$eng_args <- eng_args
   } else {
     null_args <- map_lgl(args, null_value)
-    if (any(null_args))
+    if (any(null_args)) {
       args <- args[!null_args]
-    if (length(args) > 0)
+    }
+    if (length(args) > 0) {
       object$args[names(args)] <- args
-    if (length(eng_args) > 0)
+    }
+    if (length(eng_args) > 0) {
       object$eng_args[names(eng_args)] <- eng_args
+    }
   }
 
   new_model_spec(
