@@ -25,7 +25,6 @@ test_that('pipe arguments', {
   )
 
   expect_snapshot(error = TRUE, rand_forest() |> set_args())
-
 })
 
 
@@ -47,7 +46,6 @@ test_that("can't set a mode that isn't allowed by the model spec", {
 })
 
 
-
 test_that("unavailable modes for an engine and vice-versa", {
   expect_snapshot(
     decision_tree() |>
@@ -76,7 +74,7 @@ test_that("unavailable modes for an engine and vice-versa", {
   )
 
   expect_snapshot(
-    decision_tree(engine = NULL)|>
+    decision_tree(engine = NULL) |>
       set_mode("regression") |>
       set_engine("C5.0"),
     error = TRUE
@@ -109,35 +107,20 @@ test_that("unavailable modes for an engine and vice-versa", {
 })
 
 test_that("set_* functions error when input isn't model_spec", {
-  expect_snapshot(error = TRUE,
-                  set_mode(mtcars, "regression")
-  )
+  expect_snapshot(error = TRUE, set_mode(mtcars, "regression"))
 
-  expect_snapshot(error = TRUE,
-                  set_args(mtcars, blah = "blah")
-  )
+  expect_snapshot(error = TRUE, set_args(mtcars, blah = "blah"))
 
-  expect_snapshot(error = TRUE,
-                  bag_tree |> set_mode("classification")
-  )
+  expect_snapshot(error = TRUE, bag_tree |> set_mode("classification"))
 
-  expect_snapshot(error = TRUE,
-                  bag_tree |> set_engine("rpart")
-  )
+  expect_snapshot(error = TRUE, bag_tree |> set_engine("rpart"))
 
-  expect_snapshot(error = TRUE,
-                  bag_tree |> set_args(boop = "bop")
-  )
+  expect_snapshot(error = TRUE, bag_tree |> set_args(boop = "bop"))
 
   # won't raise "info" part of error if not a parsnip-namespaced function
   # not a function
-  expect_snapshot(error = TRUE,
-                  1L |> set_args(mode = "classification")
-  )
+  expect_snapshot(error = TRUE, 1L |> set_args(mode = "classification"))
 
   # not from parsnip
-  expect_snapshot(error = TRUE,
-                  bag_tree |> set_mode("classification")
-  )
+  expect_snapshot(error = TRUE, bag_tree |> set_mode("classification"))
 })
-
