@@ -10,18 +10,25 @@ sprk <- 1:10
 class(sprk) <- c(class(sprk), "tbl_spark")
 
 tester <-
-  function(object, formula = NULL,  data = NULL, model)
-    parsnip:::check_interface(formula, data, match.call(expand.dots = TRUE), model)
+  function(object, formula = NULL, data = NULL, model) {
+    parsnip:::check_interface(
+      formula,
+      data,
+      match.call(expand.dots = TRUE),
+      model
+    )
+  }
 tester_xy <-
-  function(object, x = NULL, y = NULL, model)
+  function(object, x = NULL, y = NULL, model) {
     parsnip:::check_xy_interface(x, y, match.call(expand.dots = TRUE), model)
+  }
 
 
 test_that('good args', {
-  expect_equal(   tester(NULL, formula = f, data = hpc, model = rmod), "formula")
+  expect_equal(tester(NULL, formula = f, data = hpc, model = rmod), "formula")
   expect_equal(tester_xy(NULL, x = hpc, y = hpc, model = rmod), "data.frame")
-  expect_equal(   tester(NULL, f, data = hpc, model = rmod), "formula")
-  expect_equal(   tester(NULL, f, data = sprk, model = rmod), "formula")
+  expect_equal(tester(NULL, f, data = hpc, model = rmod), "formula")
+  expect_equal(tester(NULL, f, data = sprk, model = rmod), "formula")
 })
 
 #test_that('unnamed args', {
@@ -30,23 +37,25 @@ test_that('good args', {
 #})
 #
 test_that('wrong args', {
- expect_snapshot(error = TRUE, tester_xy(NULL, x = sprk, y = hpc, model = rmod))
- expect_snapshot(error = TRUE, tester(NULL, f,  data = as.matrix(hpc[, 1:4])))
+  expect_snapshot(
+    error = TRUE,
+    tester_xy(NULL, x = sprk, y = hpc, model = rmod)
+  )
+  expect_snapshot(error = TRUE, tester(NULL, f, data = as.matrix(hpc[, 1:4])))
 })
 
 test_that('single column df for issue #129', {
-
   expect_no_condition(
     lm1 <-
       linear_reg() |>
       set_engine("lm") |>
-      fit_xy(x = mtcars[, 2:4], y = mtcars[,1, drop = FALSE])
+      fit_xy(x = mtcars[, 2:4], y = mtcars[, 1, drop = FALSE])
   )
   expect_no_condition(
     lm2 <-
       linear_reg() |>
       set_engine("lm") |>
-      fit_xy(x = mtcars[, 2:4], y = as.matrix(mtcars)[,1, drop = FALSE])
+      fit_xy(x = mtcars[, 2:4], y = as.matrix(mtcars)[, 1, drop = FALSE])
   )
   lm3 <-
     linear_reg() |>
@@ -66,36 +75,34 @@ test_that('unknown modes', {
   )
   expect_snapshot(
     error = TRUE,
-    fit_xy(mars_spec, x = mtcars[, -1], y = mtcars[,1])
+    fit_xy(mars_spec, x = mtcars[, -1], y = mtcars[, 1])
   )
   expect_snapshot(
     error = TRUE,
-    fit_xy(mars_spec, x = lending_club[,1:2], y = lending_club$Class)
+    fit_xy(mars_spec, x = lending_club[, 1:2], y = lending_club$Class)
   )
 })
 
 test_that("misspecified formula argument", {
   rec <- structure(list(), class = "recipe")
-  expect_snapshot(error = TRUE,
-    fit(linear_reg(), rec, mtcars)
-  )
-  expect_snapshot(error = TRUE,
-    fit(linear_reg(), "boop", mtcars)
-  )
+  expect_snapshot(error = TRUE, fit(linear_reg(), rec, mtcars))
+  expect_snapshot(error = TRUE, fit(linear_reg(), "boop", mtcars))
 })
 
 test_that("elapsed time parsnip mods", {
   lm1 <-
     linear_reg() |>
     set_engine("lm") |>
-    fit_xy(x = mtcars[, 2:4], y = mtcars$mpg,
-           control = control_parsnip(verbosity = 2L))
+    fit_xy(
+      x = mtcars[, 2:4],
+      y = mtcars$mpg,
+      control = control_parsnip(verbosity = 2L)
+    )
 
   lm2 <-
     linear_reg() |>
     set_engine("lm") |>
-    fit(mpg ~ ., data = mtcars,
-        control = control_parsnip(verbosity = 2))
+    fit(mpg ~ ., data = mtcars, control = control_parsnip(verbosity = 2))
 
   expect_output(print(lm1), "Fit time:")
   expect_output(print(lm2), "Fit time:")
@@ -114,11 +121,17 @@ test_that("elapsed time parsnip mods", {
 
 test_that('No loaded engines', {
   expect_no_condition(
-    linear_reg() |> fit(mpg ~., data = mtcars)
+    linear_reg() |> fit(mpg ~ ., data = mtcars)
   )
-  expect_snapshot_error({cubist_rules() |> fit(mpg ~., data = mtcars)})
-  expect_snapshot_error({poisson_reg() |> fit(mpg ~., data = mtcars)})
-  expect_snapshot_error({cubist_rules(engine = "Cubist") |> fit(mpg ~., data = mtcars)})
+  expect_snapshot_error({
+    cubist_rules() |> fit(mpg ~ ., data = mtcars)
+  })
+  expect_snapshot_error({
+    poisson_reg() |> fit(mpg ~ ., data = mtcars)
+  })
+  expect_snapshot_error({
+    cubist_rules(engine = "Cubist") |> fit(mpg ~ ., data = mtcars)
+  })
 })
 
 test_that("fit_xy() can handle attributes on a data.frame outcome (#1060)", {
@@ -126,8 +139,9 @@ test_that("fit_xy() can handle attributes on a data.frame outcome (#1060)", {
   x <- data.frame(x = 1:5)
   y <- c(2:5, 5)
 
-  expect_silent(res <-
-                  fit_xy(lr, x = x, y =  data.frame(y = structure(y, label = "hi")))
+  expect_silent(
+    res <-
+      fit_xy(lr, x = x, y = data.frame(y = structure(y, label = "hi")))
   )
   expect_equal(res[["fit"]], fit_xy(lr, x, y)[["fit"]], ignore_attr = "label")
 })
@@ -163,17 +177,23 @@ test_that("overhead of parsnip interface is minimal (#1071)", {
   bm <- bench::mark(
     time_engine = lm(mpg ~ ., mtcars),
     time_parsnip_form = fit(linear_reg(), mpg ~ ., mtcars),
-    time_parsnip_xy = fit_xy(linear_reg(), mtcars[2:11],  mtcars[1]),
+    time_parsnip_xy = fit_xy(linear_reg(), mtcars[2:11], mtcars[1]),
     relative = TRUE,
     check = FALSE
   )
 
   expect_true(
     bm$median[2] < 3.5,
-    label = paste0("parsnip overhead factor (formula interface): ", round(bm$median[2], 4))
+    label = paste0(
+      "parsnip overhead factor (formula interface): ",
+      round(bm$median[2], 4)
+    )
   )
   expect_true(
     bm$median[3] < 3.75,
-    label = paste0("parsnip overhead factor (xy interface): ", round(bm$median[3], 4))
+    label = paste0(
+      "parsnip overhead factor (xy interface): ",
+      round(bm$median[3], 4)
+    )
   )
 })
