@@ -35,7 +35,7 @@ test_that('linear quantile regression via quantreg - single quantile', {
 
   ###
 
-  one_quant_one_row <- predict(one_quant, new_data = sac_test[1,])
+  one_quant_one_row <- predict(one_quant, new_data = sac_test[1, ])
   expect_true(nrow(one_quant_one_row) == 1L)
   expect_named(one_quant_one_row, ".pred_quantile")
   expect_true(is.list(one_quant_one_row[[1]]))
@@ -49,8 +49,11 @@ test_that('linear quantile regression via quantreg - single quantile', {
 
   one_quant_one_row_df <- as_tibble(one_quant_one_row$.pred_quantile)
   expect_s3_class(one_quant_one_row_df, c("tbl_df", "tbl", "data.frame"))
-  expect_named(one_quant_one_row_df, c(".pred_quantile", ".quantile_levels", ".row"))
-  expect_true(nrow(one_quant_one_row_df) == nrow(sac_test[1,]) * 1)
+  expect_named(
+    one_quant_one_row_df,
+    c(".pred_quantile", ".quantile_levels", ".row")
+  )
+  expect_true(nrow(one_quant_one_row_df) == nrow(sac_test[1, ]) * 1)
 })
 
 test_that('linear quantile regression via quantreg - multiple quantiles', {
@@ -61,7 +64,7 @@ test_that('linear quantile regression via quantreg - multiple quantiles', {
   ten_quant <-
     linear_reg() |>
     set_engine("quantreg") |>
-    set_mode("quantile regression", quantile_levels = (0:9)/9) |>
+    set_mode("quantile regression", quantile_levels = (0:9) / 9) |>
     fit(price ~ ., data = sac_train)
 
   expect_s3_class(ten_quant, c("_rq", "model_fit"))
@@ -78,7 +81,10 @@ test_that('linear quantile regression via quantreg - multiple quantiles', {
   )
   expect_identical(class(ten_quant_pred$.pred_quantile[[1]]), "numeric")
   expect_true(length(ten_quant_pred$.pred_quantile[[1]]) == 10L)
-  expect_identical(attr(ten_quant_pred$.pred_quantile, "quantile_levels"), (0:9)/9)
+  expect_identical(
+    attr(ten_quant_pred$.pred_quantile, "quantile_levels"),
+    (0:9) / 9
+  )
 
   ten_quant_df <- as_tibble(ten_quant_pred$.pred_quantile)
   expect_s3_class(ten_quant_df, c("tbl_df", "tbl", "data.frame"))
@@ -86,13 +92,17 @@ test_that('linear quantile regression via quantreg - multiple quantiles', {
   expect_true(nrow(ten_quant_df) == nrow(sac_test) * 10)
 
   expect_snapshot(
-    ten_quant_pred <- predict(ten_quant, new_data = sac_test, quantile_levels = (0:9)/9),
+    ten_quant_pred <- predict(
+      ten_quant,
+      new_data = sac_test,
+      quantile_levels = (0:9) / 9
+    ),
     error = TRUE
   )
 
   ###
 
-  ten_quant_one_row <- predict(ten_quant, new_data = sac_test[1,])
+  ten_quant_one_row <- predict(ten_quant, new_data = sac_test[1, ])
   expect_true(nrow(ten_quant_one_row) == 1L)
   expect_named(ten_quant_one_row, ".pred_quantile")
   expect_true(is.list(ten_quant_one_row[[1]]))
@@ -104,14 +114,14 @@ test_that('linear quantile regression via quantreg - multiple quantiles', {
   expect_true(length(ten_quant_one_row$.pred_quantile[[1]]) == 10L)
   expect_identical(
     attr(ten_quant_one_row$.pred_quantile, "quantile_levels"),
-    (0:9)/9
+    (0:9) / 9
   )
 
   ten_quant_one_row_df <- as_tibble(ten_quant_one_row$.pred_quantile)
   expect_s3_class(ten_quant_one_row_df, c("tbl_df", "tbl", "data.frame"))
-  expect_named(ten_quant_one_row_df, c(".pred_quantile", ".quantile_levels", ".row"))
-  expect_true(nrow(ten_quant_one_row_df) == nrow(sac_test[1,]) * 10)
+  expect_named(
+    ten_quant_one_row_df,
+    c(".pred_quantile", ".quantile_levels", ".row")
+  )
+  expect_true(nrow(ten_quant_one_row_df) == nrow(sac_test[1, ]) * 10)
 })
-
-
-
