@@ -1,3 +1,4 @@
+skip("waiting for keras3")
 skip_if_not_installed("modeldata")
 
 hpc <- hpc_data[1:150, c(2:5, 8)]
@@ -5,7 +6,7 @@ hpc <- hpc_data[1:150, c(2:5, 8)]
 # ------------------------------------------------------------------------------
 
 set.seed(352)
-dat <- hpc[order(runif(150)),]
+dat <- hpc[order(runif(150)), ]
 
 tr_dat <- dat[1:140, ]
 te_dat <- dat[141:150, ]
@@ -85,7 +86,6 @@ test_that('model fitting', {
       control = ctrl
     )
   )
-
 })
 
 
@@ -109,7 +109,9 @@ test_that('classification prediction', {
     predict(extract_fit_engine(lr_fit), as.matrix(te_dat[, -5]))
   keras_pred <-
     tibble::tibble(.pred_class = apply(keras_raw, 1, which.max)) |>
-    dplyr::mutate(.pred_class = factor(lr_fit$lvl[.pred_class], levels = lr_fit$lvl))
+    dplyr::mutate(
+      .pred_class = factor(lr_fit$lvl[.pred_class], levels = lr_fit$lvl)
+    )
 
   parsnip_pred <- predict(lr_fit, te_dat[, -5])
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
@@ -127,10 +129,11 @@ test_that('classification prediction', {
     predict(extract_fit_engine(plrfit), as.matrix(te_dat[, -5]))
   keras_pred <-
     tibble::tibble(.pred_class = apply(keras_raw, 1, which.max)) |>
-    dplyr::mutate(.pred_class = factor(plrfit$lvl[.pred_class], levels = plrfit$lvl))
+    dplyr::mutate(
+      .pred_class = factor(plrfit$lvl[.pred_class], levels = plrfit$lvl)
+    )
   parsnip_pred <- predict(plrfit, te_dat[, -5])
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
-
 })
 
 
@@ -175,7 +178,4 @@ test_that('classification probabilities', {
     setNames(paste0(".pred_", lr_fit$lvl))
   parsnip_pred <- predict(plrfit, te_dat[, -5], type = "prob")
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
-
 })
-
-
