@@ -4,13 +4,12 @@ hpc <- hpc_data[1:150, c(2:5, 8)]
 
 # ------------------------------------------------------------------------------
 
-
 lm_fit <-
   linear_reg(mode = "regression") |>
   set_engine("lm") |>
   fit(compounds ~ ., data = hpc)
 
-class_dat <- airquality[complete.cases(airquality),]
+class_dat <- airquality[complete.cases(airquality), ]
 class_dat$Ozone <- factor(ifelse(class_dat$Ozone >= 31, "high", "low"))
 
 lr_fit <-
@@ -18,8 +17,12 @@ lr_fit <-
   set_engine("glm") |>
   fit(Ozone ~ ., data = class_dat)
 
-class_dat2 <- airquality[complete.cases(airquality),]
-class_dat2$Ozone <- factor(ifelse(class_dat2$Ozone >= 31, "high+values", "2low"))
+class_dat2 <- airquality[complete.cases(airquality), ]
+class_dat2$Ozone <- factor(ifelse(
+  class_dat2$Ozone >= 31,
+  "high+values",
+  "2low"
+))
 
 lr_fit_2 <-
   logistic_reg() |>
@@ -29,20 +32,38 @@ lr_fit_2 <-
 # ------------------------------------------------------------------------------
 
 test_that('regression predictions', {
-  expect_true(is_tibble(predict(lm_fit, new_data = hpc[1:5,-1])))
-  expect_true(is.vector(parsnip:::predict_numeric.model_fit(lm_fit, new_data = hpc[1:5,-1])))
-  expect_equal(names(predict(lm_fit, new_data = hpc[1:5,-1])), ".pred")
+  expect_true(is_tibble(predict(lm_fit, new_data = hpc[1:5, -1])))
+  expect_true(is.vector(parsnip:::predict_numeric.model_fit(
+    lm_fit,
+    new_data = hpc[1:5, -1]
+  )))
+  expect_equal(names(predict(lm_fit, new_data = hpc[1:5, -1])), ".pred")
 })
 
 test_that('classification predictions', {
-  expect_true(is_tibble(predict(lr_fit, new_data = class_dat[1:5,-1])))
-  expect_true(is.factor(parsnip:::predict_class.model_fit(lr_fit, new_data = class_dat[1:5,-1])))
-  expect_equal(names(predict(lr_fit, new_data = class_dat[1:5,-1])), ".pred_class")
+  expect_true(is_tibble(predict(lr_fit, new_data = class_dat[1:5, -1])))
+  expect_true(is.factor(parsnip:::predict_class.model_fit(
+    lr_fit,
+    new_data = class_dat[1:5, -1]
+  )))
+  expect_equal(
+    names(predict(lr_fit, new_data = class_dat[1:5, -1])),
+    ".pred_class"
+  )
 
-  expect_true(is_tibble(predict(lr_fit, new_data = class_dat[1:5,-1], type = "prob")))
-  expect_true(is_tibble(parsnip:::predict_classprob.model_fit(lr_fit, new_data = class_dat[1:5,-1])))
-  expect_equal(names(predict(lr_fit, new_data = class_dat[1:5,-1], type = "prob")),
-               c(".pred_high", ".pred_low"))
+  expect_true(is_tibble(predict(
+    lr_fit,
+    new_data = class_dat[1:5, -1],
+    type = "prob"
+  )))
+  expect_true(is_tibble(parsnip:::predict_classprob.model_fit(
+    lr_fit,
+    new_data = class_dat[1:5, -1]
+  )))
+  expect_equal(
+    names(predict(lr_fit, new_data = class_dat[1:5, -1], type = "prob")),
+    c(".pred_high", ".pred_low")
+  )
 })
 
 
@@ -54,16 +75,18 @@ test_that('ordinal classification predictions', {
   dat_tr <-
     modeldata::sim_multinomial(
       200,
-      ~  -0.5    +  0.6 * abs(A),
-      ~ ifelse(A > 0 & B > 0, 1.0 + 0.2 * A / B, - 2),
-      ~ -0.6 * A + 0.50 * B -  A * B) |>
+      ~ -0.5 + 0.6 * abs(A),
+      ~ ifelse(A > 0 & B > 0, 1.0 + 0.2 * A / B, -2),
+      ~ -0.6 * A + 0.50 * B - A * B
+    ) |>
     dplyr::mutate(class = as.ordered(class))
   dat_te <-
     modeldata::sim_multinomial(
       5,
-      ~  -0.5    +  0.6 * abs(A),
-      ~ ifelse(A > 0 & B > 0, 1.0 + 0.2 * A / B, - 2),
-      ~ -0.6 * A + 0.50 * B -  A * B) |>
+      ~ -0.5 + 0.6 * abs(A),
+      ~ ifelse(A > 0 & B > 0, 1.0 + 0.2 * A / B, -2),
+      ~ -0.6 * A + 0.50 * B - A * B
+    ) |>
     dplyr::mutate(class = as.ordered(class))
 
   ###
@@ -90,16 +113,36 @@ test_that('ordinal classification predictions', {
 
 
 test_that('non-standard levels', {
-  expect_true(is_tibble(predict(lr_fit, new_data = class_dat[1:5,-1])))
-  expect_true(is.factor(parsnip:::predict_class.model_fit(lr_fit, new_data = class_dat[1:5,-1])))
-  expect_equal(names(predict(lr_fit, new_data = class_dat[1:5,-1])), ".pred_class")
+  expect_true(is_tibble(predict(lr_fit, new_data = class_dat[1:5, -1])))
+  expect_true(is.factor(parsnip:::predict_class.model_fit(
+    lr_fit,
+    new_data = class_dat[1:5, -1]
+  )))
+  expect_equal(
+    names(predict(lr_fit, new_data = class_dat[1:5, -1])),
+    ".pred_class"
+  )
 
-  expect_true(is_tibble(predict(lr_fit_2, new_data = class_dat2[1:5,-1], type = "prob")))
-  expect_true(is_tibble(parsnip:::predict_classprob.model_fit(lr_fit_2, new_data = class_dat2[1:5,-1])))
-  expect_equal(names(predict(lr_fit_2, new_data = class_dat2[1:5,-1], type = "prob")),
-               c(".pred_2low", ".pred_high+values"))
-  expect_equal(names(parsnip:::predict_classprob.model_fit(lr_fit_2, new_data = class_dat2[1:5,-1])),
-               c("2low", "high+values"))
+  expect_true(is_tibble(predict(
+    lr_fit_2,
+    new_data = class_dat2[1:5, -1],
+    type = "prob"
+  )))
+  expect_true(is_tibble(parsnip:::predict_classprob.model_fit(
+    lr_fit_2,
+    new_data = class_dat2[1:5, -1]
+  )))
+  expect_equal(
+    names(predict(lr_fit_2, new_data = class_dat2[1:5, -1], type = "prob")),
+    c(".pred_2low", ".pred_high+values")
+  )
+  expect_equal(
+    names(parsnip:::predict_classprob.model_fit(
+      lr_fit_2,
+      new_data = class_dat2[1:5, -1]
+    )),
+    c("2low", "high+values")
+  )
 })
 
 test_that('predict(type = "prob") with level "class" (see #720)', {
@@ -133,15 +176,16 @@ test_that('non-factor classification', {
     error = TRUE,
     logistic_reg() |>
       set_engine("glm") |>
-      fit(class ~ .,
-          data = hpc |> dplyr::mutate(class = class == "VF"))
+      fit(class ~ ., data = hpc |> dplyr::mutate(class = class == "VF"))
   )
   expect_snapshot(
     error = TRUE,
     logistic_reg() |>
       set_engine("glm") |>
-      fit(class ~ .,
-          data = hpc |> dplyr::mutate(class = ifelse(class == "VF", 1, 0)))
+      fit(
+        class ~ .,
+        data = hpc |> dplyr::mutate(class = ifelse(class == "VF", 1, 0))
+      )
   )
 
   skip_if_not_installed("glmnet")
@@ -149,8 +193,7 @@ test_that('non-factor classification', {
     error = TRUE,
     multinom_reg() |>
       set_engine("glmnet") |>
-      fit(class ~ .,
-          data = hpc |> dplyr::mutate(class = as.character(class)))
+      fit(class ~ ., data = hpc |> dplyr::mutate(class = as.character(class)))
   )
 })
 
