@@ -19,8 +19,10 @@ test_that("`print_model_spec()` handles args correctly", {
 test_that("`get_model_desc()` retrieves/creates model description well", {
   expect_equal(get_model_desc("linear_reg"), "Linear Regression")
   expect_equal(get_model_desc("boost_tree"), "Boosted Tree")
-  expect_equal(get_model_desc("boost_tree"),
-               model_descs$desc[model_descs$cls == "boost_tree"])
+  expect_equal(
+    get_model_desc("boost_tree"),
+    model_descs$desc[model_descs$cls == "boost_tree"]
+  )
 
   expect_equal(get_model_desc("goofy new class"), "goofy new class")
   expect_equal(get_model_desc("goofy_new_class"), "goofy new class")
