@@ -1,4 +1,3 @@
-
 test_that('updating', {
   expect_snapshot(
     rand_forest(mode = "regression", mtry = 2) |>
@@ -8,12 +7,19 @@ test_that('updating', {
 })
 
 test_that('bad input', {
-  expect_snapshot(res <-
-                    translate(rand_forest(mode = "classification") |>
-                                set_engine(NULL)),
-                  error = TRUE)
+  expect_snapshot(
+    res <-
+      translate(
+        rand_forest(mode = "classification") |>
+          set_engine(NULL)
+      ),
+    error = TRUE
+  )
   expect_snapshot(error = TRUE, rand_forest(mode = "time series"))
-  expect_snapshot(error = TRUE, translate(rand_forest(mode = "classification") |> set_engine("wat?")))
+  expect_snapshot(
+    error = TRUE,
+    translate(rand_forest(mode = "classification") |> set_engine("wat?"))
+  )
 })
 
 test_that("check_args() works", {
