@@ -8,15 +8,17 @@ lending_club <- head(lending_club, 200)
 num_pred <- c("funded_amnt", "annual_inc", "num_il_tl")
 
 lc_basic <- rand_forest(mode = "classification") |> set_engine("ranger")
-lc_ranger <- rand_forest(mode = "classification") |> set_engine("ranger", seed = 144)
+lc_ranger <- rand_forest(mode = "classification") |>
+  set_engine("ranger", seed = 144)
 
-bad_ranger_cls <- rand_forest(mode = "classification") |> set_engine("ranger", replace = "bad")
-bad_rf_cls <- rand_forest(mode = "classification") |> set_engine("ranger", sampsize = -10)
+bad_ranger_cls <- rand_forest(mode = "classification") |>
+  set_engine("ranger", replace = "bad")
+bad_rf_cls <- rand_forest(mode = "classification") |>
+  set_engine("ranger", sampsize = -10)
 
 # ------------------------------------------------------------------------------
 
 test_that('ranger classification execution', {
-
   skip_if_not_installed("ranger")
 
   expect_no_condition(
@@ -65,11 +67,9 @@ test_that('ranger classification execution', {
     y = lending_club$Class
   )
   expect_true(inherits(extract_fit_engine(ranger_xy_catch), "try-error"))
-
 })
 
 test_that('ranger classification prediction', {
-
   skip_if_not_installed("ranger")
 
   xy_fit <- fit_xy(
@@ -79,12 +79,19 @@ test_that('ranger classification prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(extract_fit_engine(xy_fit), data = lending_club[1:6, num_pred])$prediction
+  xy_pred <- predict(
+    extract_fit_engine(xy_fit),
+    data = lending_club[1:6, num_pred]
+  )$prediction
   xy_pred <- colnames(xy_pred)[apply(xy_pred, 1, which.max)]
   xy_pred <- factor(xy_pred, levels = levels(lending_club$Class))
   expect_equal(
     xy_pred,
-    predict(xy_fit, new_data = lending_club[1:6, num_pred], type = "class")$.pred_class
+    predict(
+      xy_fit,
+      new_data = lending_club[1:6, num_pred],
+      type = "class"
+    )$.pred_class
   )
 
   form_fit <- fit(
@@ -95,30 +102,39 @@ test_that('ranger classification prediction', {
     control = ctrl
   )
 
-  form_pred <- predict(extract_fit_engine(form_fit), data = lending_club[1:6, c("funded_amnt", "int_rate")])$prediction
+  form_pred <- predict(
+    extract_fit_engine(form_fit),
+    data = lending_club[1:6, c("funded_amnt", "int_rate")]
+  )$prediction
   form_pred <- colnames(form_pred)[apply(form_pred, 1, which.max)]
   form_pred <- factor(form_pred, levels = levels(lending_club$Class))
   expect_equal(
     form_pred,
-    predict(form_fit, new_data = lending_club[1:6, c("funded_amnt", "int_rate")])$.pred_class
+    predict(
+      form_fit,
+      new_data = lending_club[1:6, c("funded_amnt", "int_rate")]
+    )$.pred_class
   )
-
 })
 
 
 test_that('ranger classification probabilities', {
-
   skip_if_not_installed("ranger")
 
   xy_fit <- fit_xy(
-    rand_forest() |> set_mode("classification") |> set_engine("ranger", seed = 3566),
+    rand_forest() |>
+      set_mode("classification") |>
+      set_engine("ranger", seed = 3566),
     x = lending_club[, num_pred],
     y = lending_club$Class,
 
     control = ctrl
   )
 
-  xy_pred <- predict(extract_fit_engine(xy_fit), data = lending_club[1:6, num_pred])$predictions
+  xy_pred <- predict(
+    extract_fit_engine(xy_fit),
+    data = lending_club[1:6, num_pred]
+  )$predictions
   xy_pred <- as_tibble(xy_pred)
   names(xy_pred) <- paste0(".pred_", names(xy_pred))
   expect_equal(
@@ -126,27 +142,41 @@ test_that('ranger classification probabilities', {
     predict(xy_fit, new_data = lending_club[1:6, num_pred], type = "prob")
   )
 
-  one_row <- predict(xy_fit, new_data = lending_club[1, num_pred], type = "prob")
-  expect_equal(xy_pred[1,], one_row)
+  one_row <- predict(
+    xy_fit,
+    new_data = lending_club[1, num_pred],
+    type = "prob"
+  )
+  expect_equal(xy_pred[1, ], one_row)
 
   form_fit <- fit(
-    rand_forest() |> set_mode("classification") |> set_engine("ranger", seed = 3566),
+    rand_forest() |>
+      set_mode("classification") |>
+      set_engine("ranger", seed = 3566),
     Class ~ funded_amnt + int_rate,
     data = lending_club,
 
     control = ctrl
   )
 
-  form_pred <- predict(extract_fit_engine(form_fit), data = lending_club[1:6, c("funded_amnt", "int_rate")])$predictions
+  form_pred <- predict(
+    extract_fit_engine(form_fit),
+    data = lending_club[1:6, c("funded_amnt", "int_rate")]
+  )$predictions
   form_pred <- as_tibble(form_pred)
   names(form_pred) <- paste0(".pred_", names(form_pred))
   expect_equal(
     form_pred,
-    predict(form_fit, new_data = lending_club[1:6, c("funded_amnt", "int_rate")], type = "prob")
+    predict(
+      form_fit,
+      new_data = lending_club[1:6, c("funded_amnt", "int_rate")],
+      type = "prob"
+    )
   )
 
   no_prob_model <- fit_xy(
-    rand_forest(mode = "classification") |> set_engine("ranger", probability = FALSE),
+    rand_forest(mode = "classification") |>
+      set_engine("ranger", probability = FALSE),
     x = lending_club[, num_pred],
     y = lending_club$Class,
     control = ctrl
@@ -154,7 +184,10 @@ test_that('ranger classification probabilities', {
 
   expect_snapshot(
     error = TRUE,
-    parsnip:::predict_classprob.model_fit(no_prob_model, new_data = lending_club[1:6, num_pred])
+    parsnip:::predict_classprob.model_fit(
+      no_prob_model,
+      new_data = lending_club[1:6, num_pred]
+    )
   )
 })
 
@@ -164,13 +197,14 @@ num_pred <- names(mtcars)[3:6]
 
 car_basic <- rand_forest(mode = "regression") |> set_engine("ranger")
 
-bad_ranger_reg <- rand_forest(mode = "regression") |> set_engine("ranger", replace = "bad")
-bad_rf_reg <- rand_forest(mode = "regression") |> set_engine("ranger", sampsize = -10)
+bad_ranger_reg <- rand_forest(mode = "regression") |>
+  set_engine("ranger", replace = "bad")
+bad_rf_reg <- rand_forest(mode = "regression") |>
+  set_engine("ranger", sampsize = -10)
 
 # ------------------------------------------------------------------------------
 
 test_that('ranger regression execution', {
-
   skip_if_not_installed("ranger")
 
   expect_no_condition(
@@ -191,7 +225,6 @@ test_that('ranger regression execution', {
     )
   )
 
-
   ranger_form_catch <- fit(
     bad_ranger_reg,
     mpg ~ .,
@@ -207,11 +240,9 @@ test_that('ranger regression execution', {
     y = mtcars$mpg
   )
   expect_true(inherits(extract_fit_engine(ranger_xy_catch), "try-error"))
-
 })
 
 test_that('ranger regression prediction', {
-
   skip_if_not_installed("ranger")
 
   xy_fit <- fit_xy(
@@ -221,10 +252,12 @@ test_that('ranger regression prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(extract_fit_engine(xy_fit), data = tail(mtcars[, -1]))$prediction
+  xy_pred <- predict(
+    extract_fit_engine(xy_fit),
+    data = tail(mtcars[, -1])
+  )$prediction
 
   expect_equal(xy_pred, predict(xy_fit, new_data = tail(mtcars[, -1]))$.pred)
-
 })
 
 
@@ -244,30 +277,38 @@ test_that('ranger regression intervals', {
     control = ctrl
   )
 
-  rgr_pred <- predict(extract_fit_engine(xy_fit), data = head(ames_x, 3))$predictions
+  rgr_pred <- predict(
+    extract_fit_engine(xy_fit),
+    data = head(ames_x, 3)
+  )$predictions
   expect_snapshot(
     rgr_se <-
-      predict(extract_fit_engine(xy_fit), data = head(ames_x, 3), type = "se")$se
+      predict(
+        extract_fit_engine(xy_fit),
+        data = head(ames_x, 3),
+        type = "se"
+      )$se
   )
   rgr_lower <- rgr_pred - qnorm(0.035, lower.tail = FALSE) * rgr_se
   rgr_upper <- rgr_pred + qnorm(0.035, lower.tail = FALSE) * rgr_se
 
   expect_snapshot(
     parsnip_int <-
-      predict(xy_fit, new_data = head(ames_x, 3),
-              type = "conf_int", std_error = TRUE, level = 0.93
+      predict(
+        xy_fit,
+        new_data = head(ames_x, 3),
+        type = "conf_int",
+        std_error = TRUE,
+        level = 0.93
       )
   )
   expect_equal(rgr_lower, parsnip_int$.pred_lower, ignore_formula_env = TRUE)
   expect_equal(rgr_upper, parsnip_int$.pred_upper)
   expect_equal(rgr_se, parsnip_int$.std_error)
-
 })
 
 
-
 test_that('additional descriptor tests', {
-
   skip_if_not_installed("ranger")
 
   descr_xy <- fit_xy(
@@ -282,7 +323,8 @@ test_that('additional descriptor tests', {
   descr_f <- fit(
     rand_forest(mode = "regression", mtry = floor(sqrt(.cols())) + 1) |>
       set_engine("ranger"),
-    mpg ~ ., data = mtcars,
+    mpg ~ .,
+    data = mtcars,
     control = ctrl
   )
   expect_equal(extract_fit_engine(descr_f)$mtry, 4)
@@ -299,7 +341,8 @@ test_that('additional descriptor tests', {
   descr_f <- fit(
     rand_forest(mode = "regression", mtry = floor(sqrt(.cols())) + 1) |>
       set_engine("ranger"),
-    mpg ~ ., data = mtcars,
+    mpg ~ .,
+    data = mtcars,
     control = ctrl
   )
   expect_equal(extract_fit_engine(descr_f)$mtry, 4)
@@ -316,18 +359,25 @@ test_that('additional descriptor tests', {
     control = ctrl
   )
   expect_equal(extract_fit_engine(descr_other_xy)$mtry, 2)
-  expect_equal(extract_fit_engine(descr_other_xy)$call$class.weights, exp_wts,
-               ignore_formula_env = TRUE)
+  expect_equal(
+    extract_fit_engine(descr_other_xy)$call$class.weights,
+    exp_wts,
+    ignore_formula_env = TRUE
+  )
 
   descr_other_f <- fit(
     rand_forest(mode = "classification", mtry = 2) |>
       set_engine("ranger", class.weights = c(min(.lvls()), 20, 10, 1)),
-    class ~ ., data = hpc,
+    class ~ .,
+    data = hpc,
     control = ctrl
   )
   expect_equal(extract_fit_engine(descr_other_f)$mtry, 2)
-  expect_equal(extract_fit_engine(descr_other_f)$call$class.weights, exp_wts,
-               ignore_formula_env = TRUE)
+  expect_equal(
+    extract_fit_engine(descr_other_f)$call$class.weights,
+    exp_wts,
+    ignore_formula_env = TRUE
+  )
 
   descr_other_xy <- fit_xy(
     rand_forest(mode = "classification", mtry = 2) |>
@@ -337,27 +387,35 @@ test_that('additional descriptor tests', {
     control = ctrl
   )
   expect_equal(extract_fit_engine(descr_other_xy)$mtry, 2)
-  expect_equal(extract_fit_engine(descr_other_xy)$call$class.weights, exp_wts,
-               ignore_formula_env = TRUE)
+  expect_equal(
+    extract_fit_engine(descr_other_xy)$call$class.weights,
+    exp_wts,
+    ignore_formula_env = TRUE
+  )
 
   descr_other_f <- fit(
     rand_forest(mode = "classification", mtry = 2) |>
       set_engine("ranger", class.weights = c(min(.lvls()), 20, 10, 1)),
-    class ~ ., data = hpc,
+    class ~ .,
+    data = hpc,
     control = ctrl
   )
   expect_equal(extract_fit_engine(descr_other_f)$mtry, 2)
-  expect_equal(extract_fit_engine(descr_other_f)$call$class.weights, exp_wts,
-               ignore_formula_env = TRUE)
+  expect_equal(
+    extract_fit_engine(descr_other_f)$call$class.weights,
+    exp_wts,
+    ignore_formula_env = TRUE
+  )
 })
 
 
 test_that('ranger classification prediction', {
-
   skip_if_not_installed("ranger")
 
   xy_class_fit <-
-    rand_forest() |> set_mode("classification")  |> set_engine("ranger") |>
+    rand_forest() |>
+    set_mode("classification") |>
+    set_engine("ranger") |>
     fit_xy(
       x = hpc[, 1:4],
       y = hpc$class,
@@ -367,7 +425,10 @@ test_that('ranger classification prediction', {
   expect_false(has_multi_predict(xy_class_fit))
   expect_equal(multi_predict_args(xy_class_fit), NA_character_)
 
-  xy_class_pred <- predict(extract_fit_engine(xy_class_fit), data = hpc[c(1, 51, 101), 1:4])$prediction
+  xy_class_pred <- predict(
+    extract_fit_engine(xy_class_fit),
+    data = hpc[c(1, 51, 101), 1:4]
+  )$prediction
   xy_class_pred <- colnames(xy_class_pred)[apply(xy_class_pred, 1, which.max)]
   xy_class_pred <- factor(xy_class_pred, levels = levels(hpc$class))
 
@@ -386,7 +447,10 @@ test_that('ranger classification prediction', {
       control = ctrl
     )
 
-  xy_prob_pred <- predict(extract_fit_engine(xy_prob_fit), data = hpc[c(1, 51, 101), 1:4])$prediction
+  xy_prob_pred <- predict(
+    extract_fit_engine(xy_prob_fit),
+    data = hpc[c(1, 51, 101), 1:4]
+  )$prediction
   xy_prob_pred <- colnames(xy_prob_pred)[apply(xy_prob_pred, 1, which.max)]
   xy_prob_pred <- factor(xy_prob_pred, levels = levels(hpc$class))
 
@@ -395,7 +459,11 @@ test_that('ranger classification prediction', {
     predict(xy_prob_fit, new_data = hpc[c(1, 51, 101), 1:4])$.pred_class
   )
 
-  xy_prob_prob <- predict(extract_fit_engine(xy_prob_fit), data = hpc[c(1, 51, 101), 1:4], type = "response")
+  xy_prob_prob <- predict(
+    extract_fit_engine(xy_prob_fit),
+    data = hpc[c(1, 51, 101), 1:4],
+    type = "response"
+  )
   xy_prob_prob <- as_tibble(xy_prob_prob$prediction)
   names(xy_prob_prob) <- paste0(".pred_", names(xy_prob_prob))
   expect_equal(
@@ -406,7 +474,6 @@ test_that('ranger classification prediction', {
 
 
 test_that('ranger classification intervals', {
-
   skip_if_not_installed("ranger")
 
   lc_fit <- fit(
@@ -417,9 +484,16 @@ test_that('ranger classification intervals', {
     control = ctrl
   )
 
-  rgr_pred <- predict(extract_fit_engine(lc_fit), data = tail(lending_club))$predictions
+  rgr_pred <- predict(
+    extract_fit_engine(lc_fit),
+    data = tail(lending_club)
+  )$predictions
   expect_snapshot(
-    rgr_se <- predict(extract_fit_engine(lc_fit), data = tail(lending_club), type = "se")$se
+    rgr_se <- predict(
+      extract_fit_engine(lc_fit),
+      data = tail(lending_club),
+      type = "se"
+    )$se
   )
   rgr_lower <- rgr_pred - qnorm(0.035, lower.tail = FALSE) * rgr_se
   rgr_upper <- rgr_pred + qnorm(0.035, lower.tail = FALSE) * rgr_se
@@ -428,8 +502,12 @@ test_that('ranger classification intervals', {
 
   expect_snapshot(
     parsnip_int <-
-      predict(lc_fit, new_data = tail(lending_club),
-              type = "conf_int", std_error = TRUE, level = 0.93
+      predict(
+        lc_fit,
+        new_data = tail(lending_club),
+        type = "conf_int",
+        std_error = TRUE,
+        level = 0.93
       )
   )
   expect_equal(rgr_lower[, "bad"], parsnip_int$.pred_lower_bad)
@@ -438,11 +516,9 @@ test_that('ranger classification intervals', {
   expect_equal(rgr_upper[, "good"], parsnip_int$.pred_upper_good)
   expect_equal(rgr_se[, 1], parsnip_int$.std_error_bad)
   expect_equal(rgr_se[, 2], parsnip_int$.std_error_good)
-
 })
 
 
-
 test_that('ranger and sparse matrices', {
   skip_if_not_installed("ranger")
 
@@ -470,7 +546,6 @@ test_that('ranger and sparse matrices', {
 ## -----------------------------------------------------------------------------
 
 test_that('argument checks for data dimensions', {
-
   skip_if_not_installed("ranger")
 
   data(penguins, package = "modeldata")
@@ -482,16 +557,14 @@ test_that('argument checks for data dimensions', {
     set_mode("regression")
 
   expect_snapshot(
-    f_fit  <- spec |> fit(body_mass_g ~ ., data = penguins)
+    f_fit <- spec |> fit(body_mass_g ~ ., data = penguins)
   )
   expect_snapshot(
     xy_fit <- spec |> fit_xy(x = penguins[, -6], y = penguins$body_mass_g)
   )
 
-
   expect_equal(extract_fit_engine(f_fit)$mtry, 6)
   expect_equal(extract_fit_engine(f_fit)$min.node.size, nrow(penguins))
   expect_equal(extract_fit_engine(xy_fit)$mtry, 6)
   expect_equal(extract_fit_engine(xy_fit)$min.node.size, nrow(penguins))
-
 })
