@@ -3,8 +3,14 @@ test_that('adding a new model', {
 
   mod_items <- get_model_env() |> rlang::env_names()
   sponges <- grep("sponge", mod_items, value = TRUE)
-  exp_obj <- c('sponge_modes', 'sponge_fit', 'sponge_args',
-               'sponge_predict', 'sponge_pkgs', 'sponge')
+  exp_obj <- c(
+    'sponge_modes',
+    'sponge_fit',
+    'sponge_args',
+    'sponge_predict',
+    'sponge_pkgs',
+    'sponge'
+  )
   expect_equal(sort(sponges), sort(exp_obj))
 
   expect_equal(
@@ -12,36 +18,45 @@ test_that('adding a new model', {
     tibble(engine = character(0), mode = character(0))
   )
 
-expect_equal(
-  get_from_env("sponge_pkgs"),
-  tibble(engine = character(0), pkg = list(), mode = character(0))
-)
+  expect_equal(
+    get_from_env("sponge_pkgs"),
+    tibble(engine = character(0), pkg = list(), mode = character(0))
+  )
 
-expect_equal(
-  get_from_env("sponge_modes"), "unknown"
-)
+  expect_equal(
+    get_from_env("sponge_modes"),
+    "unknown"
+  )
 
-expect_equal(
-  get_from_env("sponge_args"),
-  dplyr::tibble(engine = character(0), parsnip = character(0),
-                original = character(0), func = vector("list"),
-                has_submodel = logical(0))
-)
+  expect_equal(
+    get_from_env("sponge_args"),
+    dplyr::tibble(
+      engine = character(0),
+      parsnip = character(0),
+      original = character(0),
+      func = vector("list"),
+      has_submodel = logical(0)
+    )
+  )
 
-expect_equal(
-  get_from_env("sponge_fit"),
-  tibble(engine = character(0), mode = character(0), value = vector("list"))
-)
+  expect_equal(
+    get_from_env("sponge_fit"),
+    tibble(engine = character(0), mode = character(0), value = vector("list"))
+  )
 
-expect_equal(
-  get_from_env("sponge_predict"),
-  tibble(engine = character(0), mode = character(0),
-         type = character(0), value = vector("list"))
-)
+  expect_equal(
+    get_from_env("sponge_predict"),
+    tibble(
+      engine = character(0),
+      mode = character(0),
+      type = character(0),
+      value = vector("list")
+    )
+  )
 
-expect_snapshot(error = TRUE, set_new_model())
-expect_snapshot(error = TRUE, set_new_model(2))
-expect_snapshot(error = TRUE, set_new_model(letters[1:2]))
+  expect_snapshot(error = TRUE, set_new_model())
+  expect_snapshot(error = TRUE, set_new_model(2))
+  expect_snapshot(error = TRUE, set_new_model(letters[1:2]))
 })
 
 
@@ -58,7 +73,6 @@ test_that('adding a new mode', {
   expect_equal(get_from_env("sponge_modes"), c("unknown", "classification"))
 
   expect_snapshot(error = TRUE, set_model_mode("sponge"))
-
 })
 
 
@@ -75,7 +89,10 @@ test_that('adding a new engine', {
   expect_equal(get_from_env("sponge_modes"), c("unknown", "classification"))
 
   expect_snapshot(error = TRUE, set_model_engine("sponge", eng = "gum"))
-  expect_snapshot(error = TRUE, set_model_engine("sponge", mode = "classification"))
+  expect_snapshot(
+    error = TRUE,
+    set_model_engine("sponge", mode = "classification")
+  )
   expect_snapshot(
     error = TRUE,
     set_model_engine("sponge", mode = "regression", eng = "gum")
@@ -90,7 +107,10 @@ test_that('adding a new package', {
 
   expect_snapshot(error = TRUE, set_dependency("sponge", "gum", letters[1:2]))
   expect_snapshot(error = TRUE, set_dependency("sponge", "gummies", "trident"))
-  expect_snapshot(error = TRUE, set_dependency("sponge",  "gum", "trident", mode = "regression"))
+  expect_snapshot(
+    error = TRUE,
+    set_dependency("sponge", "gum", "trident", mode = "regression")
+  )
 
   expect_equal(
     get_from_env("sponge_pkgs"),
@@ -100,16 +120,20 @@ test_that('adding a new package', {
   set_dependency("sponge", "gum", "juicy-fruit", mode = "classification")
   expect_equal(
     get_from_env("sponge_pkgs"),
-    tibble(engine = "gum",
-           pkg = list(c("trident", "juicy-fruit")),
-           mode = "classification")
+    tibble(
+      engine = "gum",
+      pkg = list(c("trident", "juicy-fruit")),
+      mode = "classification"
+    )
   )
 
   expect_equal(
     get_dependency("sponge"),
-    tibble(engine = "gum",
-           pkg = list(c("trident", "juicy-fruit")),
-           mode = "classification")
+    tibble(
+      engine = "gum",
+      pkg = list(c("trident", "juicy-fruit")),
+      mode = "classification"
+    )
   )
 })
 
@@ -140,9 +164,13 @@ test_that('adding a new argument', {
 
   expect_equal(
     get_from_env("sponge_args"),
-    tibble(engine = "gum", parsnip = "modeling", original = "modelling",
-           func = list(list(pkg = "foo", fun = "bar")),
-           has_submodel = FALSE)
+    tibble(
+      engine = "gum",
+      parsnip = "modeling",
+      original = "modelling",
+      func = list(list(pkg = "foo", fun = "bar")),
+      has_submodel = FALSE
+    )
   )
 
   expect_snapshot(
@@ -252,7 +280,6 @@ test_that('adding a new argument', {
 })
 
 
-
 # ------------------------------------------------------------------------------
 
 test_that('adding a new fit', {
@@ -273,7 +300,7 @@ test_that('adding a new fit', {
 
   fit_env_data <- get_from_env("sponge_fit")
   expect_equal(
-    fit_env_data[ 1:2],
+    fit_env_data[1:2],
     tibble(engine = "gum", mode = "classification")
   )
 
@@ -405,7 +432,7 @@ test_that('adding a new predict method', {
 
   pred_env_data <- get_from_env("sponge_predict")
   expect_equal(
-    pred_env_data[ 1:3],
+    pred_env_data[1:3],
     tibble(engine = "gum", mode = "classification", type = "class")
   )
 
@@ -415,7 +442,7 @@ test_that('adding a new predict method', {
   )
 
   expect_equal(
-    get_pred_type("sponge", "class")[ 1:3],
+    get_pred_type("sponge", "class")[1:3],
     tibble(engine = "gum", mode = "classification", type = "class")
   )
 
@@ -446,7 +473,6 @@ test_that('adding a new predict method', {
     )
   )
 
-
   expect_snapshot(
     error = TRUE,
     set_pred(
@@ -520,11 +546,9 @@ test_that('adding a new predict method', {
       value = class_vals_2
     )
   )
-
 })
 
 
-
 test_that('showing model info', {
   expect_snapshot(show_model_info("rand_forest"))
 
@@ -532,4 +556,3 @@ test_that('showing model info', {
   # notation would be ambiguous (#1000)
   expect_snapshot(show_model_info("mlp"))
 })
-
