@@ -5,7 +5,8 @@ hpc <- hpc_data[1:150, c(2:5, 8)]
 # ------------------------------------------------------------------------------
 
 test_that('engine arguments', {
-  kernlab_cv <- svm_rbf(mode = "regression") |> set_engine("kernlab", cross = 10)
+  kernlab_cv <- svm_rbf(mode = "regression") |>
+    set_engine("kernlab", cross = 10)
 
   expect_snapshot(translate(kernlab_cv, "kernlab")$method$fit$args)
 })
@@ -21,18 +22,21 @@ test_that('updating', {
 
 test_that('bad input', {
   expect_snapshot(error = TRUE, svm_rbf(mode = "reallyunknown"))
-  expect_snapshot(error = TRUE, translate(svm_rbf(mode = "regression") |> set_engine( NULL)))
+  expect_snapshot(
+    error = TRUE,
+    translate(svm_rbf(mode = "regression") |> set_engine(NULL))
+  )
 })
 
 # ------------------------------------------------------------------------------
 
 reg_mod <-
-  svm_rbf(mode = "regression", rbf_sigma = .1, cost = 1/4) |>
+  svm_rbf(mode = "regression", rbf_sigma = .1, cost = 1 / 4) |>
   set_engine("kernlab") |>
   set_mode("regression")
 
 cls_mod <-
-  svm_rbf(mode = "classification", rbf_sigma = .1, cost = 1/8) |>
+  svm_rbf(mode = "classification", rbf_sigma = .1, cost = 1 / 8) |>
   set_engine("kernlab") |>
   set_mode("classification")
 
@@ -41,14 +45,13 @@ ctrl <- control_parsnip(verbosity = 0, catch = FALSE)
 # ------------------------------------------------------------------------------
 
 test_that('svm poly regression', {
-
   skip_if_not_installed("kernlab")
 
   expect_no_condition(
     res <- fit_xy(
       reg_mod,
       control = ctrl,
-      x = hpc[,2:4],
+      x = hpc[, 2:4],
       y = hpc$input_fields
     )
   )
@@ -63,15 +66,13 @@ test_that('svm poly regression', {
       control = ctrl
     )
   )
-
 })
 
 
 test_that('svm rbf regression prediction', {
-
   skip_if_not_installed("kernlab")
 
-  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128),] |>
+  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128), ] |>
     droplevels()
 
   ind <- c(2, 1, 143)
@@ -87,13 +88,16 @@ test_that('svm rbf regression prediction', {
   kern_pred <-
     structure(
       list(.pred = c(131.7743, 372.0932, 902.0633)),
-      row.names = c(NA, -3L), class = c("tbl_df", "tbl", "data.frame"))
+      row.names = c(NA, -3L),
+      class = c("tbl_df", "tbl", "data.frame")
+    )
 
   parsnip_pred <- predict(reg_form, hpc[ind, -c(2, 5)])
-  expect_equal(as.data.frame(kern_pred),
-               as.data.frame(parsnip_pred),
-               tolerance = .0001)
-
+  expect_equal(
+    as.data.frame(kern_pred),
+    as.data.frame(parsnip_pred),
+    tolerance = .0001
+  )
 
   reg_xy_form <-
     fit_xy(
@@ -102,21 +106,25 @@ test_that('svm rbf regression prediction', {
       y = hpc$input_fields,
       control = ctrl
     )
-  expect_equal(extract_fit_engine(reg_form)@alphaindex, extract_fit_engine(reg_xy_form)@alphaindex)
+  expect_equal(
+    extract_fit_engine(reg_form)@alphaindex,
+    extract_fit_engine(reg_xy_form)@alphaindex
+  )
 
   parsnip_xy_pred <- predict(reg_xy_form, hpc[ind, -c(2, 5)])
-  expect_equal(as.data.frame(kern_pred),
-               as.data.frame(parsnip_xy_pred),
-               tolerance = .0001)
+  expect_equal(
+    as.data.frame(kern_pred),
+    as.data.frame(parsnip_xy_pred),
+    tolerance = .0001
+  )
 })
 
 # ------------------------------------------------------------------------------
 
 test_that('svm rbf classification', {
-
   skip_if_not_installed("kernlab")
 
-  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128),] |>
+  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128), ] |>
     droplevels()
 
   ind <- c(2, 1, 143)
@@ -138,15 +146,13 @@ test_that('svm rbf classification', {
       control = ctrl
     )
   )
-
 })
 
 
 test_that('svm rbf classification probabilities', {
-
   skip_if_not_installed("kernlab")
 
-  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128),] |>
+  hpc_no_m <- hpc[-c(84, 85, 86, 87, 88, 109, 128), ] |>
     droplevels()
 
   ind <- c(4, 55, 143)
@@ -161,11 +167,17 @@ test_that('svm rbf classification probabilities', {
     )
 
   kern_class <-
-    structure(list(
-      .pred_class = structure(
-        c(1L, 1L, 3L),
-        .Label = c("VF", "F", "L"), class = "factor")),
-      row.names = c(NA, -3L), class = c("tbl_df", "tbl", "data.frame"))
+    structure(
+      list(
+        .pred_class = structure(
+          c(1L, 1L, 3L),
+          .Label = c("VF", "F", "L"),
+          class = "factor"
+        )
+      ),
+      row.names = c(NA, -3L),
+      class = c("tbl_df", "tbl", "data.frame")
+    )
 
   parsnip_class <- predict(cls_form, hpc_no_m[ind, -5])
   expect_equal(kern_class, parsnip_class)
@@ -182,7 +194,11 @@ test_that('svm rbf classification probabilities', {
 
   library(kernlab)
   kern_probs <-
-    kernlab::predict(extract_fit_engine(cls_form), hpc_no_m[ind, -5], type = "probabilities") |>
+    kernlab::predict(
+      extract_fit_engine(cls_form),
+      hpc_no_m[ind, -5],
+      type = "probabilities"
+    ) |>
     as_tibble() |>
     setNames(c('.pred_VF', '.pred_F', '.pred_L'))
 
